# user-avatars

rock-avatars

## 测试

```
pytest --cov=rock_avatars/
```

## 上传安装包

```
python setup.py sdist build
```

```
twine upload dist/*
```

## 数据文件目录结构

```
tree ./data
./data
├── background.png
├── cloth
│   └── cloth.png
├── eye
│   └── eyes.png
├── hair
│   ├── hair.png
│   └── hair2.png
├── horn
│   └── horn.png
└── mouth
    ├── mouth.png
    └── mouth2.png

5 directories, 8 files
```

## 用法

安装依赖

```
pip install rock-avatars
```

```
import rock_avatars as rf

avatar = rf.Avatar(
    "./data",
    "background.png",
    [
        "mouth",
        "horn",
        "hair",
        "eye",
        "cloth",
    ],
)
avatar.generate()
```

# Development

Activate Virtual Environment

```
make
source venv/bin/activate
```

To install all of the dependencies necessary for development, run:

```
pip install -e '.[develop]'
```

To run all of the tests, run:

```
python setup.py test
```